@@ -5,16 +5,12 @@ use utf8;
 use OrePAN2;
 use IO::Uncompress::Gunzip ('$GunzipError');
 
-use Class::Accessor::Lite 0.05 (
-    rw => [qw(no_mtime)],
-);
-
 sub new {
     my $class = shift;
     my %args = @_==1 ? %{$_[0]} : @_;
     bless {
         index => {},
-        no_mtime => 0,
+        %args,
     }, $class;
 }
 
@@ -38,10 +34,9 @@ sub load {
         last unless /\S/;
     }
 
-    my $method = $opts->{replace} ? 'replace_index' : 'add_index';
     while (<$fh>) {
         if (/^(\S+)\s+(\S+)\s+(.*)$/) {
-           $self->$method($1,$2 eq 'undef' ? undef : $2,$3);
+           $self->add_index($1,$2 eq 'undef' ? undef : $2,$3);
         }
     }
 
@@ -67,22 +62,22 @@ sub delete_index {
     return;
 }
 
-sub replace_index {
-    my ($self, $package, $version, $archive_file) = @_;
-    $self->{index}->{$package} = [$version, $archive_file];
-}
-
 sub add_index {
     my ($self, $package, $version, $archive_file) = @_;
 
     if ($self->{index}{$package}) {
-        Carp::croak("${package} is already indexed.");
+        my ($orig_ver) = @{$self->{index}{$package}};
+        if (version->parse($orig_ver) >= version->parse($version)) {
+            return;
+        }
     }
     $self->{index}->{$package} = [$version, $archive_file];
 }
 
 sub as_string {
-    my $self = shift;
+    my ($self, $opts) = @_;
+    $opts ||= +{};
+    my $simple = $opts->{simple} || 0;
 
     my @buf;
 
@@ -92,9 +87,11 @@ sub as_string {
         'Description:  DarkPAN',
         'Columns:      package name, version, path',
         'Intended-For: Automated fetch routines, namespace documentation.',
-        "Written-By:   OrePAN2 $OrePAN2::VERSION",
-        "Line-Count:   @{[ scalar(keys %{$self->{index}}) ]}",
-        (!$self->{no_mtime} ? "Last-Updated: @{[ scalar localtime ]}" : ()),
+        $simple ? () : (
+            "Written-By:   OrePAN2 $OrePAN2::VERSION",
+            "Line-Count:   @{[ scalar(keys %{$self->{index}}) ]}",
+            "Last-Updated: @{[ scalar localtime ]}",
+        ),
         '',
     );
 
